Index: test/unittests/interpreter/bytecode-array-builder-unittest.cc |
diff --git a/test/unittests/interpreter/bytecode-array-builder-unittest.cc b/test/unittests/interpreter/bytecode-array-builder-unittest.cc |
index 21de16f03849124c3640ff7993bffd61a131f883..839215f743220550b256ae52c875eb2f62cfaf84 100644 |
--- a/test/unittests/interpreter/bytecode-array-builder-unittest.cc |
+++ b/test/unittests/interpreter/bytecode-array-builder-unittest.cc |
@@ -297,9 +297,11 @@ TEST_F(BytecodeArrayBuilderTest, AllBytecodesGenerated) { |
CHECK_EQ(final_bytecode, Bytecode::kReturn); |
CHECK_EQ(scorecard[Bytecodes::ToByte(final_bytecode)], 1); |
-#define CHECK_BYTECODE_PRESENT(Name, ...) \ |
- /* Check Bytecode is marked in scorecard */ \ |
- CHECK_GE(scorecard[Bytecodes::ToByte(Bytecode::k##Name)], 1); |
+#define CHECK_BYTECODE_PRESENT(Name, ...) \ |
+ /* Check Bytecode is marked in scorecard, unless it's a debug break */ \ |
+ if (!Bytecodes::IsDebugBreak(Bytecode::k##Name)) { \ |
+ CHECK_GE(scorecard[Bytecodes::ToByte(Bytecode::k##Name)], 1); \ |
+ } |
BYTECODE_LIST(CHECK_BYTECODE_PRESENT) |
#undef CHECK_BYTECODE_PRESENT |
} |